@@ -47,11 +47,29 @@ class _fill_in_known_wildcards(object):
     ----------
     wildcard_values : tuple of index values
         a tuple containing index values to substitute into the slice wildcards
+
+    look_in_index : :py:class:`bool` [optional]
+        If True, the iterator will also look for matches using the
+        components' underlying index_set() in addition to the (sparse)
+        indices matched by the components' __contains__()
+        method. [default: False]
+
+    get_if_not_present : :py:class:`bool` [optional]
+        If True, the iterator will attempt to retrieve data objects
+        (through getitem) for indexes that match the underlying
+        component index_set() but do not appear in the (sparse) indices
+        matched by __contains__.  get_if_not_present implies
+        look_in_index.  [default: False]
+
     """
-    def __init__(self, wildcard_values):
+    def __init__(self, wildcard_values,
+                 look_in_index=False,
+                 get_if_not_present=False):
         self.base_key = wildcard_values
         self.key = list(wildcard_values)
         self.known_slices = set()
+        self.look_in_index = look_in_index or get_if_not_present
+        self.get_if_not_present = get_if_not_present
 
     def __call__(self, _slice):
         """Advance the specified slice generator, substituting wildcard values
@@ -97,11 +115,20 @@ class _fill_in_known_wildcards(object):
         elif len(idx) == 1 and idx[0] in _slice.component:
             _slice.last_index = idx
             return _slice.component[idx[0]]
-        else:
-            raise KeyError(
-                "Index %s is not valid for indexed component '%s' "
-                "(found evaluating slice index %s)"
-                % (idx, _slice.component.name, self.base_key))
+        elif self.look_in_index:
+            if idx in _slice.component.index_set():
+                _slice.last_index = idx
+                return _slice.component[idx] if self.get_if_not_present \
+                    else None
+            elif len(idx) == 1 and idx[0] in _slice.component.index_set():
+                _slice.last_index = idx
+                return _slice.component[idx[0]] if self.get_if_not_present \
+                    else None
+
+        raise KeyError(
+            "Index %s is not valid for indexed component '%s' "
+            "(found evaluating slice index %s)"
+            % (idx, _slice.component.name, self.base_key))
 
     def check_complete(self):
         if self.key:
@@ -113,12 +140,43 @@ class SliceEllipsisLookupError(Exception):
     pass
 
 class _ReferenceDict(collections_MutableMapping):
+    """A dict-like object whose values are defined by a slice.
+
+    This implements a dict-like object whose keys and values are defined
+    by a component slice (:py:class:`_IndexedComponent_slice`).  The
+    intent behind this object is to replace the normal ``_data``
+    :py:class:`dict` in :py:class:`IndexedComponent` containers to
+    create "reference" components.
+
+    Parameters
+    ----------
+    component_slice : :py:class:`_IndexedComponent_slice`
+        The slice object that defines the "members" of this mutable mapping.
+    """
     def __init__(self, component_slice):
         self._slice = component_slice
 
+    def __contains__(self, key):
+        try:
+            advance_iterator(self._get_iter(self._slice, key))
+            return True
+        except (StopIteration, KeyError):
+            return False
+        except SliceEllipsisLookupError:
+            if type(key) is tuple and len(key) == 1:
+                key = key[0]
+            # Brute force (linear time) lookup
+            _iter = iter(self._slice)
+            for item in _iter:
+                if _iter.get_last_index_wildcards() == key:
+                    return True
+            return False
+
     def __getitem__(self, key):
         try:
-            return advance_iterator(self._get_iter(self._slice, key))
+            return advance_iterator(
+                self._get_iter(self._slice, key, get_if_not_present=True)
+            )
         except StopIteration:
             raise KeyError("KeyError: %s" % (key,))
         except SliceEllipsisLookupError:
@@ -153,7 +211,7 @@ class _ReferenceDict(collections_MutableMapping):
             raise DeveloperError(
                 "Unexpected slice _call_stack operation: %s" % op)
         try:
-            advance_iterator(self._get_iter(tmp, key))
+            advance_iterator(self._get_iter(tmp, key, get_if_not_present=True))
         except StopIteration:
             pass
 
@@ -195,12 +253,6 @@ class _ReferenceDict(collections_MutableMapping):
     def __len__(self):
         return sum(1 for i in self._slice)
 
-    def __contains__(self, key):
-        try:
-            return super(_ReferenceDict, self).__contains__(key)
-        except (AttributeError, KeyError):
-            return False
-
     def iteritems(self):
         """Return the wildcard, value tuples for this ReferenceDict
 
@@ -231,28 +283,68 @@ class _ReferenceDict(collections_MutableMapping):
         """
         return iter(self._slice)
 
-    def _get_iter(self, _slice, key):
+    def _get_iter(self, _slice, key, get_if_not_present=False):
         if key.__class__ not in (tuple, list):
             key = (key,)
         return _IndexedComponent_slice_iter(
-            _slice, _fill_in_known_wildcards(flatten_tuple(key)))
+            _slice,
+            _fill_in_known_wildcards(flatten_tuple(key),
+                                     get_if_not_present=get_if_not_present)
+        )
 
 if six.PY3:
     _ReferenceDict.items = _ReferenceDict.iteritems
     _ReferenceDict.values = _ReferenceDict.itervalues
 
 class _ReferenceSet(collections_Set):
-    def __init__(self, ref_dict):
-        self._ref = ref_dict
+    """A set-like object whose values are defined by a slice.
+
+    This implements a dict-like object whose members are defined by a
+    component slice (:py:class:`_IndexedComponent_slice`).
+    :py:class:`_ReferenceSet` differs from the
+    :py:class:`_ReferenceDict` above in that it looks in the underlying
+    component ``index_set()`` for values that match the slice, and not
+    just the (sparse) indices defined by the slice.
+
+    Parameters
+    ----------
+    component_slice : :py:class:`_IndexedComponent_slice`
+        The slice object that defines the "members" of this set
+
+    """
+    def __init__(self, component_slice):
+        self._slice = component_slice
 
     def __contains__(self, key):
-        return key in self._ref
+        try:
+            advance_iterator(self._get_iter(self._slice, key))
+            return True
+        except (StopIteration, KeyError):
+            return False
+        except SliceEllipsisLookupError:
+            if type(key) is tuple and len(key) == 1:
+                key = key[0]
+            # Brute force (linear time) lookup
+            _iter = iter(self._slice)
+            for item in _iter:
+                if _iter.get_last_index_wildcards() == key:
+                    return True
+            return False
 
     def __iter__(self):
-        return iter(self._ref)
+        return self._slice.index_wildcard_keys()
 
     def __len__(self):
-        return len(self._ref)
+        return sum(1 for _ in self)
+
+    def _get_iter(self, _slice, key):
+        if key.__class__ not in (tuple, list):
+            key = (key,)
+        return _IndexedComponent_slice_iter(
+            _slice,
+            _fill_in_known_wildcards(flatten_tuple(key), look_in_index=True),
+            iter_over_index=True
+        )
 
 
 def _get_base_sets(_set):
@@ -460,8 +552,8 @@ def Reference(reference, ctype=_NotSpecified):
         # more than one ctype.
         elif len(ctypes) > 1:
             break
-    if index is None:
-        index = SetOf(_ReferenceSet(_data))
+    if not index:
+        index = SetOf(_ReferenceSet(reference))
     else:
         wildcards = sum((sorted(iteritems(lvl)) for lvl in index
                          if lvl is not None), [])
