@@ -22,6 +22,7 @@ else:
 # These packages contain plugins that need to be loaded
 #
 _packages = [
+    'pyomo.common',
     'pyomo.opt',
     'pyomo.core',
     'pyomo.dataportal',
@@ -47,10 +48,14 @@ _packages = [
 _optional_packages = set([
     'pyomo.contrib.example',
     'pyomo.contrib.preprocessing',
+    'pyomo.contrib.mindtpy',
     'pyomo.contrib.gdpopt',
+    'pyomo.contrib.gdpbb',
     'pyomo.contrib.gdp_bounds',
     'pyomo.contrib.trustregion',
     'pyomo.contrib.multistart',
+    'pyomo.contrib.petsc',
+    'pyomo.contrib.mcpp',
 ])
 
 
@@ -100,3 +105,5 @@ from pyomo.opt import (
     SolverFactory, SolverManagerFactory, UnknownSolver,
     TerminationCondition, SolverStatus,
     )
+from pyomo.core.base.units_container import units
+
