@@ -28,8 +28,8 @@ class PyomoMIPTestDriver(Plugin):
 
     def setUpClass(self, cls, options):
         try:
-            cls.pico_convert =  pyomo.common.registered_executable("pico_convert")
-            cls.pico_convert_available= (not cls.pico_convert is None)
+            cls.pico_convert =  pyomo.common.Executable("pico_convert")
+            cls.pico_convert_available= cls.pico_convert.available()
         except pyutilib.common.ApplicationError:
             cls.pico_convert_available=False
 
